@@ -112,7 +112,7 @@ latexmk = function(
     )
     if (is.null(pdf_file)) out = file.path(output_dir, out)
   }
-  if (is.null(pdf_file)) pdf_file = out
+  if (is.null(pdf_file)) pdf_file = with_ext(file, ext)
   check_pdf = function() {
     if (!file.exists(out)) show_latex_error(file, with_ext(out, 'log'), TRUE)
     xfun::file_rename(out, pdf_file)
@@ -625,6 +625,7 @@ detect_files = function(text) {
     }
     if (p == r$fd) v = tolower(v)  # LGRcmr.fd -> lgrcmr.fd
     if (!(p %in% r$font)) return(v)
+    v = gsub('^.*?:|:.*$', '', v)  # https://github.com/rstudio/tinytex/issues/465
     if (p == r$font[1]) paste0(v, '.sty') else font_ext(v)
   })))
 }
